@@ -137,6 +137,7 @@ class LoggerClass():
         if LABEL_LOG_LEVELS: log_format += ' [%(levelname)-8s]'
         log_format += ' %(message)s'
         logging.basicConfig(format=log_format, datefmt='%Y-%m-%d %H:%M:%S', level=logger_verbosity_map[str(log_level)])
+        self.LOG = logging.getLogger('dsocli')
 
     def set_verbosity(self, log_level):
         self.__level = log_level
@@ -144,62 +145,62 @@ class LoggerClass():
 
     def critical(self, msg, force=True):
         if force or self.level >= log_levels['critical']: 
-            saveLevel = logging.root.level
+            saveLevel = self.LOG.root.level
             try:
-                logging.root.level=logging.DEBUG
-                logging.critical(format_text(msg, 'critical'))
+                self.LOG.root.level=logging.DEBUG
+                self.LOG.critical(format_text(msg, 'critical'))
             finally:
-                logging.root.level=saveLevel
+                self.LOG.root.level=saveLevel
 
     def error(self, msg, force=True):
         if force or self.level >= log_levels['error']: 
-            saveLevel = logging.root.level
+            saveLevel = self.LOG.root.level
             try:
-                logging.root.level=logging.DEBUG
-                logging.error(format_text(msg, 'error'))
+                self.LOG.root.level=logging.DEBUG
+                self.LOG.error(format_text(msg, 'error'))
             finally:
-                logging.root.level=saveLevel
+                self.LOG.root.level=saveLevel
 
     def warn(self, msg, force=False):
         if force or self.level >= log_levels['warning']: 
-            saveLevel = logging.root.level
+            saveLevel = self.LOG.root.level
             try:
-                logging.root.level=logging.DEBUG
-                logging.warning(format_text(msg, 'warning'))
+                self.LOG.root.level=logging.DEBUG
+                self.LOG.warning(format_text(msg, 'warning'))
             finally:
-                logging.root.level=saveLevel
+                self.LOG.root.level=saveLevel
 
     def info(self, msg, stress=True, force=False):
         if force or self.level >= log_levels['info']: 
-            saveLevel = logging.root.level
+            saveLevel = self.LOG.root.level
             try:
-                logging.root.level=logging.DEBUG
-                logging.info(format_text(msg, 'info'))
+                self.LOG.root.level=logging.DEBUG
+                self.LOG.info(format_text(msg, 'info'))
             finally:
-                logging.root.level=saveLevel
+                self.LOG.root.level=saveLevel
 
     ###--------------------------------------------------------------------------------------------
 
     ### log debug message if (requested) log_level is greater than LOG_LEVEL_debug
     def debug(self, msg, force=False):
         if force or self.level >= log_levels['debug']: 
-            saveLevel = logging.root.level
+            saveLevel = self.LOG.root.level
             try:
-                logging.root.level=logging.DEBUG
-                logging.debug(format_text(msg, 'debug'))
+                self.LOG.root.level=logging.DEBUG
+                self.LOG.debug(format_text(msg, 'debug'))
             finally:
-                logging.root.level=saveLevel
+                self.LOG.root.level=saveLevel
 
     ###--------------------------------------------------------------------------------------------
 
     # ### always log
     # def force(self, msg, stress=True):
-    #     saveLevel = logging.root.level
+    #     saveLevel = self.LOG.root.level
     #     try:
-    #         logging.root.level=logging.DEBUG
-    #         logging.info(format_text(msg, 'bold' if stress else 'normal'))
+    #         self.LOG.root.level=logging.DEBUG
+    #         self.LOG.info(format_text(msg, 'bold' if stress else 'normal'))
     #     finally:
-    #         logging.root.level=saveLevel
+    #         self.LOG.root.level=saveLevel
 
 
 ###--------------------------------------------------------------------------------------------
