@@ -8,8 +8,8 @@ import boto3
 from botocore.exceptions import ClientError
 from dsocli.exceptions import DSOException
 from dsocli.logger import Logger
-from dsocli.config import Config
-from dsocli.providers import ProviderManager
+from dsocli.config import Configs
+from dsocli.providers import Providers
 from dsocli.parameters import ParameterProvider
 from dsocli.stages import Stages
 from dsocli.constants import *
@@ -272,4 +272,4 @@ class AwsSsmParameterProvider(ParameterProvider):
 ###--------------------------------------------------------------------------------------------
 ###--------------------------------------------------------------------------------------------
 
-ProviderManager.register(AwsSsmParameterProvider())
+Providers.register(AwsSsmParameterProvider())
