@@ -8,8 +8,8 @@ import boto3
 from botocore.exceptions import ClientError
 from dsocli.exceptions import DSOException
 from dsocli.logger import Logger
-from dsocli.config import Config
-from dsocli.providers import ProviderManager
+from dsocli.config import Configs
+from dsocli.providers import Providers
 from dsocli.secrets import SecretProvider
 from dsocli.stages import Stages
 from dsocli.constants import *
@@ -274,4 +274,4 @@ class AwsSsmSecretProvider(SecretProvider):
 ###--------------------------------------------------------------------------------------------
 ###--------------------------------------------------------------------------------------------
 
-ProviderManager.register(AwsSsmSecretProvider())
+Providers.register(AwsSsmSecretProvider())
