@@ -1,33 +1,9 @@
 
 import re
-from .config import Config
-from .providers import ProviderManager
 from .constants import *
 from .exceptions import DSOException
 
 class Stages():
-    # @staticmethod
-    # def list(stage):
-    #     pass
-    
-    # @staticmethod
-    # def create(stage):
-    #     m = re.match(REGEX_PATTERNS['stage'], stage)
-    #     stage = m.groups()[0]
-    #     stage = m.groups()[1] if len(m.groups()) > 1 else 'default'
-    #     # contexts = Config.app_spec['contexts']
-    #     # if contexts is None:
-    #     #     Config.app_spec['contexts'] = {}
-    #     #     contexts = {}
-    #     # contexts[stage][stage] = 1
-    #     Config.app_spec['contexts'][stage][stage] = 1
-    # @staticmethod
-    # def download(stage):
-    #     pass
-    # @staticmethod
-    # def delete(stage):
-    #     pass
-
 
     @staticmethod
     def default_stage():
